@@ -9,11 +9,11 @@ Poker::Eval::Badugi - Evaluate and score Badugi poker hands.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -26,7 +26,7 @@ extends 'Poker::Eval';
 
 sub best_hand {
   my ( $self, $hole ) = @_;
-  my $best = { score => 0 };
+  my $best = Poker::Hand->new(cards => $hole);
   my $iter = combinations( $hole, scalar @$hole > 4 ? 4 : scalar @$hole);
   while (my $combo = $iter->next ) {
     my (@list, %seen);
@@ -38,14 +38,12 @@ sub best_hand {
       }
     }
     my $score = $self->scorer->score( [@list] );
-    if ( defined $score && $score >= $best->{score} ) {
-      $best = {
-        score => $score,
-        hand  => \@list,
-      };
+    if ( defined $score && $score >= $best->score ) {
+      $best->score($score);
+      $best->best_combo(\@list);
     }
   }
-  $best->{name} = $self->scorer->hand_name( $best->{score} );
+  $best->name($self->scorer->hand_name( $best->score ));
   return $best;
 }
 
